==> haskell-data-clist-0.1.2.3-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.2.3
id: data-clist-0.1.2.3-GvnLLpQY880LhEdRcKP98I
key: data-clist-0.1.2.3-GvnLLpQY880LhEdRcKP98I
license: BSD-3-Clause
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
author: John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
abi: 5a92205c17ddbd93fec3c2143d671a61
exposed: True
exposed-modules:
    Data.CircularList
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-clist-0.1.2.3
hs-libraries: HSdata-clist-0.1.2.3-GvnLLpQY880LhEdRcKP98I
depends:
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-clist-0.1.2.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-clist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-clist
version: 0.1.2.3
id: data-clist-0.1.2.3-3WHh9VXalZZJLSNR95mGmR
key: data-clist-0.1.2.3-3WHh9VXalZZJLSNR95mGmR
license: BSD-3-Clause
maintainer: Jeremy Huffman <jeremy@jeremyhuffman.com>, John Van Enk <vanenkj@gmail.com>
author: John Van Enk <vanenkj@gmail.com>
stability: experimental
homepage: https://github.com/sw17ch/data-clist
synopsis: Simple functional ring type.
description:
    Simple functional bidirectional ring type.
    Given that the ring terminiology clashes with certain
    mathematical branches, we'\''re using the term CList or
    CircularList instead.
category: Data Structures
abi: 58bfab1a0593611dd5a7b19491e25022
exposed: True
exposed-modules:
    Data.CircularList
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-clist-0.1.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-clist-0.1.2.3
hs-libraries: HSdata-clist-0.1.2.3-3WHh9VXalZZJLSNR95mGmR
depends:
    QuickCheck-2.13.2-2FrYL0Zx0JL1157x99MUYA base-4.12.0.0
    deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-data-clist/html/data-clist.haddock
haddock-html: /usr/share/doc/haskell-data-clist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
